from _typeshed import Incomplete
from java import jclass as jclass
from typing import Any

class OnClickListener(Incomplete):
    def __init__(self, fn: callable) -> None: ...
    def onClick(self, _view) -> None: ...

class OnLongClickListener(Incomplete):
    def __init__(self, fn: callable) -> None: ...
    def onLongClick(self, _view): ...

def run_on_ui_thread(func: callable, delay: int = 0): ...
def log(data: Any): ...

class R(Incomplete):
    def __init__(self, fn) -> None: ...
    def run(self) -> None: ...
