from _typeshed import Incomplete
from java import jarray as jarray
from typing import Any

JavaClass: Incomplete
JavaObject: Incomplete

def find_class(class_name: str) -> JavaClass | None: ...
def get_private_field(obj: JavaObject, field_name: str) -> Any | None: ...
def set_private_field(obj: JavaObject, field_name: str, new_value: Any) -> bool: ...
def get_static_private_field(clazz: JavaClass, field_name: str) -> Any | None: ...
def set_static_private_field(
    clazz: JavaClass, field_name: str, new_value: Any
) -> bool: ...
